/* 
 *  Author: Chris Lord <chris@openedhand.com>
 *
 *  Copyright (c) 2007 OpenedHand Ltd - http://www.openedhand.com/
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */

/**
 * SECTION:jana-ecal-utils
 * @short_description: A set of utility functions for libjana-ecal
 *
 * jana-ecal-utils contains a set of libjana-ecal related utility functions.
 */

#include <libical/icaltime.h>
#include <libecal/e-cal-time-util.h>
#include <libjana-ecal/jana-ecal-time.h>
#include "jana-ecal-utils.h"

/**
 * jana_ecal_utils_time_now:
 * @location: A full timezone name
 *
 * Creates a new #JanaEcalTime with the current time of the given location.
 *
 * Returns: A new #JanaEcalTime, cast as a #JanaTime.
 */
JanaTime *
jana_ecal_utils_time_now (const gchar *location)
{
	icaltimetype ical_time;
	const icaltimezone *zone;
	
	zone = (const icaltimezone *)icaltimezone_get_builtin_timezone (
		location);
	ical_time = icaltime_current_time_with_zone (zone);
	icaltime_set_timezone (&ical_time, zone);

	return jana_ecal_time_new_from_icaltime (&ical_time);
}

/**
 * jana_ecal_utils_time_today:
 * @location: A full timezone name
 *
 * Creates a new #JanaEcalTime with the current date of the given location.
 *
 * Returns: A new #JanaEcalTime, cast as a #JanaTime.
 */
JanaTime *
jana_ecal_utils_time_today (const gchar *location)
{
	JanaTime *time;
	icaltimetype ical_time;
	const icaltimezone *zone;
	
	zone = (const icaltimezone *)icaltimezone_get_builtin_timezone (
		location);
	ical_time = icaltime_current_time_with_zone (zone);
	icaltime_set_timezone (&ical_time, zone);

	time = jana_ecal_time_new_from_icaltime (&ical_time);
	jana_time_set_isdate (time, TRUE);

	return time;
}

